@@ -148,7 +148,7 @@ static void cally_actor_finalize   (GObject *obj);
 static AtkObject*            cally_actor_get_parent          (AtkObject *obj);
 static gint                  cally_actor_get_index_in_parent (AtkObject *obj);
 static AtkStateSet*          cally_actor_ref_state_set       (AtkObject *obj);
-static G_CONST_RETURN gchar* cally_actor_get_name            (AtkObject *obj);
+static const gchar*          cally_actor_get_name            (AtkObject *obj);
 static gint                  cally_actor_get_n_children      (AtkObject *obj);
 static AtkObject*            cally_actor_ref_child           (AtkObject *obj,
                                                              gint       i);
@@ -195,11 +195,11 @@ static gboolean              cally_actor_action_do_action       (AtkAction *acti
                                                                 gint       i);
 static gboolean              idle_do_action                    (gpointer data);
 static gint                  cally_actor_action_get_n_actions   (AtkAction *action);
-static G_CONST_RETURN gchar* cally_actor_action_get_description (AtkAction *action,
+static const gchar*          cally_actor_action_get_description (AtkAction *action,
                                                                 gint       i);
-static G_CONST_RETURN gchar* cally_actor_action_get_keybinding  (AtkAction *action,
+static const gchar*          cally_actor_action_get_keybinding  (AtkAction *action,
                                                                 gint       i);
-static G_CONST_RETURN gchar* cally_actor_action_get_name        (AtkAction *action,
+static const gchar*          cally_actor_action_get_name        (AtkAction *action,
                                                                 gint       i);
 static gboolean              cally_actor_action_set_description (AtkAction   *action,
                                                                 gint         i,
@@ -420,10 +420,10 @@ cally_actor_finalize (GObject *obj)
 
 /* AtkObject */
 
-static G_CONST_RETURN gchar*
+static const gchar*
 cally_actor_get_name (AtkObject *obj)
 {
-  G_CONST_RETURN gchar* name = NULL;
+  const gchar* name = NULL;
 
   g_return_val_if_fail (CALLY_IS_ACTOR (obj), NULL);
 
@@ -583,13 +583,11 @@ static gint
 cally_actor_get_n_children (AtkObject *obj)
 {
   ClutterActor     *actor    = NULL;
-  CallyActorPrivate *priv     = NULL;
   GList            *children = NULL;
   gint              num      = 0;
 
   g_return_val_if_fail (CALLY_IS_ACTOR (obj), 0);
 
-  priv = CALLY_ACTOR (obj)->priv;
   actor = CALLY_GET_CLUTTER_ACTOR (obj);
 
   if (actor == NULL) /* State is defunct */
@@ -618,13 +616,11 @@ cally_actor_ref_child (AtkObject *obj,
 {
   ClutterActor     *actor    = NULL;
   ClutterActor     *child    = NULL;
-  CallyActorPrivate *priv     = NULL;
   GList            *children = NULL;
   AtkObject        *result   = NULL;
 
   g_return_val_if_fail (CALLY_IS_ACTOR (obj), NULL);
 
-  priv = CALLY_ACTOR (obj)->priv;
   actor = CALLY_GET_CLUTTER_ACTOR (obj);
 
   if (actor == NULL) /* State is defunct */
@@ -982,15 +978,13 @@ static gboolean
 cally_actor_action_do_action (AtkAction *action,
                              gint       index)
 {
-  ClutterActor        *actor      = NULL;
   CallyActor           *cally_actor = NULL;
-  AtkStateSet         *set        = NULL;
-  CallyActorPrivate    *priv       = NULL;
-  CallyActorActionInfo *info       = NULL;
+  AtkStateSet          *set         = NULL;
+  CallyActorPrivate    *priv        = NULL;
+  CallyActorActionInfo *info        = NULL;
 
   cally_actor = CALLY_ACTOR (action);
   priv = cally_actor->priv;
-  actor = CALLY_GET_CLUTTER_ACTOR (cally_actor);
 
   set = atk_object_ref_state_set (ATK_OBJECT (cally_actor));
 
@@ -1063,7 +1057,7 @@ cally_actor_action_get_n_actions (AtkAction *action)
   return g_list_length (priv->action_list);
 }
 
-static G_CONST_RETURN gchar*
+static const gchar*
 cally_actor_action_get_name (AtkAction *action,
                             gint       i)
 {
@@ -1080,7 +1074,7 @@ cally_actor_action_get_name (AtkAction *action,
   return info->name;
 }
 
-static G_CONST_RETURN gchar*
+static const gchar*
 cally_actor_action_get_description (AtkAction *action,
                                    gint       i)
 {
@@ -1118,7 +1112,7 @@ cally_actor_action_set_description (AtkAction   *action,
   return TRUE;
 }
 
-static G_CONST_RETURN gchar*
+static const gchar*
 cally_actor_action_get_keybinding (AtkAction *action,
                                   gint       i)
 {
@@ -1414,9 +1408,9 @@ cally_actor_add_action (CallyActor      *cally_actor,
  *
  * Return value: added action id, or -1 if failure
  *
- * Since: 1.6
- *
  * Rename to: cally_actor_add_action
+ *
+ * Since: 1.6
  */
 guint
 cally_actor_add_action_full (CallyActor          *cally_actor,
