@@ -426,7 +426,7 @@ gboolean              clutter_actor_get_paint_visibility      (ClutterActor
 
 void                  clutter_actor_set_name                  (ClutterActor          *self,
                                                                const gchar           *name);
-G_CONST_RETURN gchar *clutter_actor_get_name                  (ClutterActor          *self);
+const gchar *         clutter_actor_get_name                  (ClutterActor          *self);
 
 guint32               clutter_actor_get_gid                   (ClutterActor          *self);
 void                  clutter_actor_set_clip                  (ClutterActor          *self,
@@ -497,7 +497,7 @@ gboolean              clutter_actor_event                     (ClutterActor
                                                                ClutterEvent          *event,
                                                                gboolean               capture);
 
-ClutterActor *        clutter_get_actor_by_gid                (guint32                id);
+ClutterActor *        clutter_get_actor_by_gid                (guint32                id_);
 
 gboolean              clutter_actor_set_shader                (ClutterActor          *self,
                                                                ClutterShader         *shader);
