@@ -145,6 +145,7 @@
 #include "clutter-debug.h"
 #include "clutter-enum-types.h"
 #include "clutter-interval.h"
+#include "clutter-marshal.h"
 #include "clutter-private.h"
 #include "clutter-scriptable.h"
 #include "clutter-script-private.h"
@@ -158,9 +159,13 @@ enum
   PROP_DURATION,
   PROP_LOOP,
   PROP_TIMELINE,
-  PROP_ALPHA
+  PROP_ALPHA,
+
+  PROP_LAST
 };
 
+static GParamSpec *obj_props[PROP_LAST];
+
 enum
 {
   STARTED,
@@ -195,23 +200,27 @@ G_DEFINE_TYPE_WITH_CODE (ClutterAnimation, clutter_animation, G_TYPE_OBJECT,
                                                 clutter_scriptable_init));
 
 static void
-on_actor_dispose (gpointer  user_data,
-                  GObject  *actor_pointer)
+on_actor_destroy (ClutterActor     *actor,
+                  ClutterAnimation *animation)
 {
-  ClutterAnimation *self = user_data;
+  ClutterAnimationPrivate *priv = animation->priv;
+  GObject *obj = G_OBJECT (actor);
 
-  if (self->priv->object == actor_pointer)
+  if (obj == priv->object)
     {
-      CLUTTER_NOTE (ANIMATION, "Object [%p] was unref'd", actor_pointer);
-      g_object_unref (self);
+      g_object_set_qdata (priv->object, quark_object_animation, NULL);
+      g_signal_handlers_disconnect_by_func (priv->object,
+                                            G_CALLBACK (on_actor_destroy),
+                                            animation);
+      g_object_unref (animation);
     }
 }
 
-
 static void
 clutter_animation_real_completed (ClutterAnimation *self)
 {
   ClutterAnimationPrivate *priv = self->priv;
+  ClutterAnimatable *animatable = NULL;
   ClutterAnimation *animation;
   ClutterTimeline *timeline;
   ClutterTimelineDirection direction;
@@ -221,6 +230,9 @@ clutter_animation_real_completed (ClutterAnimation *self)
   timeline = clutter_animation_get_timeline (self);
   direction = clutter_timeline_get_direction (timeline);
 
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    animatable = CLUTTER_ANIMATABLE (priv->object);
+
   /* explicitly set the final state of the animation */
   CLUTTER_NOTE (ANIMATION, "Set final state on object [%p]", priv->object);
   g_hash_table_iter_init (&iter, priv->properties);
@@ -235,7 +247,10 @@ clutter_animation_real_completed (ClutterAnimation *self)
       else
         p_value = clutter_interval_peek_initial_value (interval);
 
-      g_object_set_property (priv->object, p_name, p_value);
+      if (animatable != NULL)
+        clutter_animatable_set_final_state (animatable, p_name, p_value);
+      else
+        g_object_set_property (priv->object, p_name, p_value);
     }
 
   /* at this point, if this animation was created by clutter_actor_animate()
@@ -253,7 +268,9 @@ clutter_animation_real_completed (ClutterAnimation *self)
                     priv->object);
 
       g_object_set_qdata (priv->object, quark_object_animation, NULL);
-      g_object_weak_unref (priv->object, on_actor_dispose, self);
+      g_signal_handlers_disconnect_by_func (priv->object,
+                                            G_CALLBACK (on_actor_destroy),
+                                            animation);
 
       CLUTTER_NOTE (ANIMATION, "Releasing the reference Animation [%p]",
                     animation);
@@ -426,7 +443,6 @@ static void
 clutter_animation_class_init (ClutterAnimationClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  GParamSpec *pspec;
 
   quark_object_animation =
     g_quark_from_static_string ("clutter-actor-animation");
@@ -447,12 +463,12 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_object ("object",
-                               "Object",
-                               "Object to which the animation applies",
-                               G_TYPE_OBJECT,
-                               CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_OBJECT, pspec);
+  obj_props[PROP_OBJECT] =
+    g_param_spec_object ("object",
+                         P_("Object"),
+                         P_("Object to which the animation applies"),
+                         G_TYPE_OBJECT,
+                         CLUTTER_PARAM_READWRITE);
 
   /**
    * ClutterAnimation:mode:
@@ -463,13 +479,13 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_ulong ("mode",
-                              "Mode",
-                              "The mode of the animation",
-                              0, G_MAXULONG,
-                              CLUTTER_LINEAR,
-                              CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_MODE, pspec);
+  obj_props[PROP_MODE] =
+    g_param_spec_ulong ("mode",
+                        P_("Mode"),
+                        P_("The mode of the animation"),
+                        0, G_MAXULONG,
+                        CLUTTER_LINEAR,
+                        CLUTTER_PARAM_READWRITE);
 
   /**
    * ClutterAnimation:duration:
@@ -478,12 +494,13 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_uint ("duration",
-                             "Duration",
-                             "Duration of the animation, in milliseconds",
-                             0, G_MAXUINT, 0,
-                             CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_DURATION, pspec);
+  obj_props[PROP_DURATION] =
+    g_param_spec_uint ("duration",
+                       P_("Duration"),
+                       P_("Duration of the animation, in milliseconds"),
+                       0, G_MAXUINT,
+                       0,
+                       CLUTTER_PARAM_READWRITE);
 
   /**
    * ClutterAnimation:loop:
@@ -492,12 +509,12 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_boolean ("loop",
-                                "Loop",
-                                "Whether the animation should loop",
-                                FALSE,
-                                CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_LOOP, pspec);
+  obj_props[PROP_LOOP] =
+    g_param_spec_boolean ("loop",
+                          P_("Loop"),
+                          P_("Whether the animation should loop"),
+                          FALSE,
+                          CLUTTER_PARAM_READWRITE);
 
   /**
    * ClutterAnimation:timeline:
@@ -506,12 +523,12 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_object ("timeline",
-                               "Timeline",
-                               "The timeline used by the animation",
-                               CLUTTER_TYPE_TIMELINE,
-                               CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_TIMELINE, pspec);
+  obj_props[PROP_TIMELINE] =
+    g_param_spec_object ("timeline",
+                         P_("Timeline"),
+                         P_("The timeline used by the animation"),
+                         CLUTTER_TYPE_TIMELINE,
+                         CLUTTER_PARAM_READWRITE);
 
   /**
    * ClutterAnimation:alpha:
@@ -520,12 +537,16 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
    *
    * Since: 1.0
    */
-  pspec = g_param_spec_object ("alpha",
-                               "Alpha",
-                               "The alpha used by the animation",
-                               CLUTTER_TYPE_ALPHA,
-                               CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_ALPHA, pspec);
+  obj_props[PROP_ALPHA] =
+    g_param_spec_object ("alpha",
+                         P_("Alpha"),
+                         P_("The alpha used by the animation"),
+                         CLUTTER_TYPE_ALPHA,
+                         CLUTTER_PARAM_READWRITE);
+
+  _clutter_object_class_install_properties (gobject_class,
+                                            PROP_LAST,
+                                            obj_props);
 
   /**
    * ClutterAnimation::started:
@@ -542,7 +563,7 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ClutterAnimationClass, started),
                   NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
+                  _clutter_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 
   /**
@@ -563,7 +584,7 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ClutterAnimationClass, completed),
                   NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
+                  _clutter_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 }
 
@@ -580,6 +601,7 @@ clutter_animation_init (ClutterAnimation *self)
 
 static inline void
 clutter_animation_bind_property_internal (ClutterAnimation *animation,
+                                          const gchar      *property_name,
                                           GParamSpec       *pspec,
                                           ClutterInterval  *interval)
 {
@@ -589,17 +611,18 @@ clutter_animation_bind_property_internal (ClutterAnimation *animation,
     {
       g_warning ("Cannot bind property '%s': the interval is out "
                  "of bounds",
-                 pspec->name);
+                 property_name);
       return;
     }
 
   g_hash_table_insert (priv->properties,
-                       g_strdup (pspec->name),
+                       g_strdup (property_name),
                        g_object_ref_sink (interval));
 }
 
 static inline void
 clutter_animation_update_property_internal (ClutterAnimation *animation,
+                                            const gchar      *property_name,
                                             GParamSpec       *pspec,
                                             ClutterInterval  *interval)
 {
@@ -609,12 +632,12 @@ clutter_animation_update_property_internal (ClutterAnimation *animation,
     {
       g_warning ("Cannot bind property '%s': the interval is out "
                  "of bounds",
-                 pspec->name);
+                 property_name);
       return;
     }
 
   g_hash_table_replace (priv->properties,
-                        g_strdup (pspec->name),
+                        g_strdup (property_name),
                         g_object_ref_sink (interval));
 }
 
@@ -624,7 +647,6 @@ clutter_animation_validate_bind (ClutterAnimation *animation,
                                  GType             argtype)
 {
   ClutterAnimationPrivate *priv;
-  GObjectClass *klass;
   GParamSpec *pspec;
   GType pspec_type;
 
@@ -647,9 +669,20 @@ clutter_animation_validate_bind (ClutterAnimation *animation,
       return NULL;
     }
 
-  klass = G_OBJECT_GET_CLASS (priv->object);
-  pspec = g_object_class_find_property (klass, property_name);
-  if (!pspec)
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    {
+      ClutterAnimatable *animatable = CLUTTER_ANIMATABLE (priv->object);
+
+      pspec = clutter_animatable_find_property (animatable, property_name);
+    }
+  else
+    {
+      GObjectClass *klass = G_OBJECT_GET_CLASS (priv->object);
+
+      pspec = g_object_class_find_property (klass, property_name);
+    }
+
+  if (pspec == NULL)
     {
       g_warning ("Cannot bind property '%s': objects of type '%s' have "
                  "no such property",
@@ -667,8 +700,9 @@ clutter_animation_validate_bind (ClutterAnimation *animation,
 
   pspec_type = G_PARAM_SPEC_VALUE_TYPE (pspec);
 
-  if (!g_value_type_compatible (argtype, pspec_type) ||
-      !g_value_type_transformable (argtype, pspec_type))
+  if (g_value_type_transformable (argtype, pspec_type))
+    return pspec;
+  else
     {
       g_warning ("Cannot bind property '%s': the interval value of "
                  "type '%s' is not compatible with the property value "
@@ -678,8 +712,6 @@ clutter_animation_validate_bind (ClutterAnimation *animation,
                  g_type_name (pspec_type));
       return NULL;
     }
-
-  return pspec;
 }
 
 /**
@@ -715,7 +747,9 @@ clutter_animation_bind_interval (ClutterAnimation *animation,
   if (pspec == NULL)
     return NULL;
 
-  clutter_animation_bind_property_internal (animation, pspec, interval);
+  clutter_animation_bind_property_internal (animation, property_name,
+                                            pspec,
+                                            interval);
 
   return animation;
 }
@@ -748,6 +782,7 @@ clutter_animation_bind (ClutterAnimation *animation,
   ClutterInterval *interval;
   GType type;
   GValue initial = { 0, };
+  GValue real_final = { 0, };
 
   g_return_val_if_fail (CLUTTER_IS_ANIMATION (animation), NULL);
   g_return_val_if_fail (property_name != NULL, NULL);
@@ -759,13 +794,39 @@ clutter_animation_bind (ClutterAnimation *animation,
   if (pspec == NULL)
     return NULL;
 
+  g_value_init (&real_final, G_PARAM_SPEC_VALUE_TYPE (pspec));
+  if (!g_value_transform (final, &real_final))
+    {
+      g_value_unset (&real_final);
+      g_warning ("Unable to transform the value of type '%s' to a value "
+                 "of '%s' compatible with the property '%s'of the object "
+                 "of type '%s'",
+                 g_type_name (type),
+                 g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
+                 property_name,
+                 G_OBJECT_TYPE_NAME (priv->object));
+      return NULL;
+    }
+
   g_value_init (&initial, G_PARAM_SPEC_VALUE_TYPE (pspec));
-  g_object_get_property (priv->object, property_name, &initial);
 
-  interval = clutter_interval_new_with_values (type, &initial, final);
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    clutter_animatable_get_initial_state (CLUTTER_ANIMATABLE (priv->object),
+                                          property_name,
+                                          &initial);
+  else
+    g_object_get_property (priv->object, property_name, &initial);
+
+  interval = clutter_interval_new_with_values (G_PARAM_SPEC_VALUE_TYPE (pspec),
+                                               &initial,
+                                               &real_final);
+
   g_value_unset (&initial);
+  g_value_unset (&real_final);
 
-  clutter_animation_bind_property_internal (animation, pspec, interval);
+  clutter_animation_bind_property_internal (animation, property_name,
+                                            pspec,
+                                            interval);
 
   return animation;
 }
@@ -845,7 +906,6 @@ clutter_animation_update_interval (ClutterAnimation *animation,
                                    ClutterInterval  *interval)
 {
   ClutterAnimationPrivate *priv;
-  GObjectClass *klass;
   GParamSpec *pspec;
   GType pspec_type, int_type;
 
@@ -863,9 +923,20 @@ clutter_animation_update_interval (ClutterAnimation *animation,
       return;
     }
 
-  klass = G_OBJECT_GET_CLASS (priv->object);
-  pspec = g_object_class_find_property (klass, property_name);
-  if (!pspec)
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    {
+      ClutterAnimatable *animatable = CLUTTER_ANIMATABLE (priv->object);
+
+      pspec = clutter_animatable_find_property (animatable, property_name);
+    }
+  else
+    {
+      GObjectClass *klass = G_OBJECT_GET_CLASS (priv->object);
+
+      pspec = g_object_class_find_property (klass, property_name);
+    }
+
+  if (pspec == NULL)
     {
       g_warning ("Cannot update property '%s': objects of type '%s' have "
                  "no such property",
@@ -889,7 +960,9 @@ clutter_animation_update_interval (ClutterAnimation *animation,
       return;
     }
 
-  clutter_animation_update_property_internal (animation, pspec, interval);
+  clutter_animation_update_property_internal (animation, property_name,
+                                              pspec,
+                                              interval);
 }
 
 /**
@@ -1050,7 +1123,12 @@ on_alpha_notify (GObject          *gobject,
         }
 
       if (apply)
-        g_object_set_property (priv->object, p_name, &value);
+        {
+          if (is_animatable)
+            clutter_animatable_set_final_state (animatable, p_name, &value);
+          else
+            g_object_set_property (priv->object, p_name, &value);
+        }
 
       g_value_unset (&value);
     }
@@ -1081,7 +1159,7 @@ clutter_animation_get_alpha_internal (ClutterAnimation *animation)
 
       priv->alpha = g_object_ref_sink (alpha);
 
-      g_object_notify (G_OBJECT (animation), "alpha");
+      _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_ALPHA]);
     }
 
   return priv->alpha;
@@ -1116,7 +1194,7 @@ clutter_animation_get_timeline_internal (ClutterAnimation *animation)
   /* the alpha owns the timeline now */
   g_object_unref (timeline);
 
-  g_object_notify (G_OBJECT (animation), "timeline");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_TIMELINE]);
 
   return timeline;
 }
@@ -1181,7 +1259,7 @@ clutter_animation_set_object (ClutterAnimation *animation,
   if (object != NULL)
     priv->object = g_object_ref (object);
 
-  g_object_notify (G_OBJECT (animation), "object");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_OBJECT]);
 }
 
 /**
@@ -1230,7 +1308,7 @@ clutter_animation_set_mode (ClutterAnimation *animation,
 
   clutter_alpha_set_mode (alpha, mode);
 
-  g_object_notify (G_OBJECT (animation), "mode");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_MODE]);
 
   g_object_thaw_notify (G_OBJECT (animation));
 }
@@ -1272,7 +1350,7 @@ clutter_animation_get_mode (ClutterAnimation *animation)
  */
 void
 clutter_animation_set_duration (ClutterAnimation *animation,
-                                gint              msecs)
+                                guint             msecs)
 {
   ClutterTimeline *timeline;
 
@@ -1286,7 +1364,7 @@ clutter_animation_set_duration (ClutterAnimation *animation,
   clutter_timeline_set_duration (timeline, msecs);
   clutter_timeline_rewind (timeline);
 
-  g_object_notify (G_OBJECT (animation), "duration");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_DURATION]);
 
   g_object_thaw_notify (G_OBJECT (animation));
 }
@@ -1319,7 +1397,7 @@ clutter_animation_set_loop (ClutterAnimation *animation,
   timeline = clutter_animation_get_timeline_internal (animation);
   clutter_timeline_set_loop (timeline, loop);
 
-  g_object_notify (G_OBJECT (animation), "loop");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_LOOP]);
 
   g_object_thaw_notify (G_OBJECT (animation));
 }
@@ -1412,9 +1490,9 @@ clutter_animation_set_timeline (ClutterAnimation *animation,
 
   alpha = clutter_animation_get_alpha_internal (animation);
   clutter_alpha_set_timeline (alpha, timeline);
-  g_object_notify (G_OBJECT (animation), "timeline");
-  g_object_notify (G_OBJECT (animation), "duration");
-  g_object_notify (G_OBJECT (animation), "loop");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_TIMELINE]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_DURATION]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_LOOP]);
 
   if (timeline)
     {
@@ -1542,11 +1620,11 @@ clutter_animation_set_alpha (ClutterAnimation *animation,
 
 out:
   /* emit all relevant notifications */
-  g_object_notify (G_OBJECT (animation), "mode");
-  g_object_notify (G_OBJECT (animation), "duration");
-  g_object_notify (G_OBJECT (animation), "loop");
-  g_object_notify (G_OBJECT (animation), "alpha");
-  g_object_notify (G_OBJECT (animation), "timeline");
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_MODE]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_DURATION]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_LOOP]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_ALPHA]);
+  _clutter_notify_by_pspec (G_OBJECT (animation), obj_props[PROP_TIMELINE]);
 
   g_object_thaw_notify (G_OBJECT (animation));
 }
@@ -1688,26 +1766,39 @@ done:
       GValue cur_value = { 0, };
 
       g_value_init (&cur_value, G_PARAM_SPEC_VALUE_TYPE (pspec));
-      g_object_get_property (priv->object, property_name, &cur_value);
+
+      if (CLUTTER_IS_ANIMATABLE (priv->object))
+        clutter_animatable_get_initial_state (CLUTTER_ANIMATABLE (priv->object),
+                                              property_name,
+                                              &cur_value);
+      else
+        g_object_get_property (priv->object, property_name, &cur_value);
 
       interval =
         clutter_interval_new_with_values (G_PARAM_SPEC_VALUE_TYPE (pspec),
                                           &cur_value,
                                           &real_value);
 
-      if (!clutter_animation_has_property (animation, pspec->name))
-        clutter_animation_bind_property_internal (animation,
+      if (!clutter_animation_has_property (animation, property_name))
+        clutter_animation_bind_property_internal (animation, property_name,
                                                   pspec,
                                                   interval);
       else
-        clutter_animation_update_property_internal (animation,
+        clutter_animation_update_property_internal (animation, property_name,
                                                     pspec,
                                                     interval);
 
       g_value_unset (&cur_value);
     }
   else
-    g_object_set_property (priv->object, property_name, &real_value);
+    {
+      if (CLUTTER_IS_ANIMATABLE (priv->object))
+        clutter_animatable_set_final_state (CLUTTER_ANIMATABLE (priv->object),
+                                            property_name,
+                                            &real_value);
+      else
+        g_object_set_property (priv->object, property_name, &real_value);
+    }
 
   g_value_unset (&real_value);
 }
@@ -1719,16 +1810,20 @@ clutter_animation_setupv (ClutterAnimation    *animation,
                           const GValue        *values)
 {
   ClutterAnimationPrivate *priv = animation->priv;
-  GObjectClass *klass;
+  ClutterAnimatable *animatable = NULL;
+  GObjectClass *klass = NULL;
   gint i;
-  gboolean is_fixed = FALSE;
 
-  klass = G_OBJECT_GET_CLASS (priv->object);
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    animatable = CLUTTER_ANIMATABLE (priv->object);
+  else
+    klass = G_OBJECT_GET_CLASS (priv->object);
 
   for (i = 0; i < n_properties; i++)
     {
       const gchar *property_name = properties[i];
       GParamSpec *pspec;
+      gboolean is_fixed = FALSE;
 
       if (g_str_has_prefix (property_name, "fixed::"))
         {
@@ -1736,8 +1831,12 @@ clutter_animation_setupv (ClutterAnimation    *animation,
           is_fixed = TRUE;
         }
 
-      pspec = g_object_class_find_property (klass, property_name);
-      if (!pspec)
+      if (animatable != NULL)
+        pspec = clutter_animatable_find_property (animatable, property_name);
+      else
+        pspec = g_object_class_find_property (klass, property_name);
+
+      if (pspec == NULL)
         {
           g_warning ("Cannot bind property '%s': objects of type '%s' do "
                      "not have this property",
@@ -1792,10 +1891,14 @@ clutter_animation_setup_valist (ClutterAnimation *animation,
                                 va_list           var_args)
 {
   ClutterAnimationPrivate *priv = animation->priv;
-  GObjectClass *klass;
+  ClutterAnimatable *animatable = NULL;
+  GObjectClass *klass = NULL;
   const gchar *property_name;
 
-  klass = G_OBJECT_GET_CLASS (priv->object);
+  if (CLUTTER_IS_ANIMATABLE (priv->object))
+    animatable = CLUTTER_ANIMATABLE (priv->object);
+  else
+    klass = G_OBJECT_GET_CLASS (priv->object);
 
   property_name = first_property_name;
   while (property_name != NULL)
@@ -1827,8 +1930,13 @@ clutter_animation_setup_valist (ClutterAnimation *animation,
               is_fixed = TRUE;
             }
 
-          pspec = g_object_class_find_property (klass, property_name);
-          if (!pspec)
+          if (animatable != NULL)
+            pspec = clutter_animatable_find_property (animatable,
+                                                      property_name);
+          else
+            pspec = g_object_class_find_property (klass, property_name);
+
+          if (pspec == NULL)
             {
               g_warning ("Cannot bind property '%s': objects of type '%s' do "
                          "not have this property",
@@ -1837,15 +1945,9 @@ clutter_animation_setup_valist (ClutterAnimation *animation,
               break;
             }
 
-#if GLIB_CHECK_VERSION (2, 23, 2)
           G_VALUE_COLLECT_INIT (&final, G_PARAM_SPEC_VALUE_TYPE (pspec),
                                 var_args, 0,
                                 &error);
-#else
-          /* this is the same as G_VALUE_COLLECT_INIT(), but slower */
-          g_value_init (&final, G_PARAM_SPEC_VALUE_TYPE (pspec));
-          G_VALUE_COLLECT (&final, var_args, 0, &error);
-#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
 
           if (error)
             {
@@ -1876,7 +1978,13 @@ animation_create_for_actor (ClutterActor *actor)
       animation = clutter_animation_new ();
       clutter_animation_set_object (animation, object);
       g_object_set_qdata (object, quark_object_animation, animation);
-      g_object_weak_ref (object, on_actor_dispose, animation);
+
+      /* use the ::destroy signal to get a notification
+       * that the actor went away mid-animation
+       */
+      g_signal_connect (object, "destroy",
+                        G_CALLBACK (on_actor_destroy),
+                        animation);
 
       CLUTTER_NOTE (ANIMATION,
                     "Created new Animation [%p] for actor [%p]",
@@ -1899,7 +2007,7 @@ animation_create_for_actor (ClutterActor *actor)
  * @actor: a #ClutterActor
  * @alpha: a #ClutterAlpha
  * @first_property_name: the name of a property
- * @VarArgs: a %NULL terminated list of property names and
+ * @Varargs: a %NULL terminated list of property names and
  *   property values
  *
  * Animates the given list of properties of @actor between the current
@@ -1956,7 +2064,7 @@ clutter_actor_animate_with_alpha (ClutterActor *actor,
  * @mode: an animation mode logical id
  * @timeline: a #ClutterTimeline
  * @first_property_name: the name of a property
- * @VarArgs: a %NULL terminated list of property names and
+ * @Varargs: a %NULL terminated list of property names and
  *   property values
  *
  * Animates the given list of properties of @actor between the current
@@ -2007,7 +2115,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * @mode: an animation mode logical id
  * @duration: duration of the animation, in milliseconds
  * @first_property_name: the name of a property
- * @VarArgs: a %NULL terminated list of property names and
+ * @Varargs: a %NULL terminated list of property names and
  *   property values
  *
  * Animates the given list of properties of @actor between the current
@@ -2374,3 +2482,56 @@ clutter_actor_get_animation (ClutterActor *actor)
 
   return g_object_get_qdata (G_OBJECT (actor), quark_object_animation);
 }
+
+/**
+ * clutter_actor_detach_animation:
+ * @actor: a #ClutterActor
+ *
+ * Detaches the #ClutterAnimation used by @actor, if clutter_actor_animate()
+ * has been called on @actor.
+ *
+ * Once the animation has been detached, it loses a reference. If it was
+ * the only reference then the #ClutterAnimation becomes invalid.
+ *
+ * The #ClutterAnimation::completed signal will not be emitted.
+ *
+ * Since: 1.4
+ */
+void
+clutter_actor_detach_animation (ClutterActor *actor)
+{
+  ClutterAnimation *animation;
+  ClutterAnimationPrivate *priv;
+
+  g_return_if_fail (CLUTTER_IS_ACTOR (actor));
+
+  animation = g_object_get_qdata (G_OBJECT (actor), quark_object_animation);
+  if (animation == NULL)
+    return;
+
+  priv = animation->priv;
+
+  g_assert (priv->object == G_OBJECT (actor));
+
+  /* we can't call get_timeline_internal() here because it would be
+   * pointless to create a timeline on an animation we want to detach
+   */
+  if (priv->alpha != NULL)
+    {
+      ClutterTimeline *timeline;
+
+      timeline = clutter_alpha_get_timeline (priv->alpha);
+      if (timeline != NULL)
+        clutter_timeline_stop (timeline);
+    }
+
+  /* disconnect the ::destroy handler added by animation_create_for_actor() */
+  g_signal_handlers_disconnect_by_func (actor,
+                                        G_CALLBACK (on_actor_destroy),
+                                        animation);
+
+  clutter_animation_set_object (animation, NULL);
+
+  /* drop the reference on the animation */
+  g_object_unref (animation);
+}
