@@ -117,7 +117,7 @@ void                 clutter_animator_set                        (ClutterAnimato
                                                                   const gchar          *first_property_name,
                                                                   guint                 first_mode,
                                                                   gdouble               first_progress,
-                                                                  ...);
+                                                                  ...) G_GNUC_NULL_TERMINATED;
 GList              * clutter_animator_get_keys                   (ClutterAnimator      *animator,
                                                                   GObject              *object,
                                                                   const gchar          *property_name,
@@ -161,7 +161,7 @@ void                 clutter_animator_property_set_interpolation (ClutterAnimato
 
 GType                 clutter_animator_key_get_type          (void) G_GNUC_CONST;
 GObject *             clutter_animator_key_get_object        (const ClutterAnimatorKey *key);
-G_CONST_RETURN gchar *clutter_animator_key_get_property_name (const ClutterAnimatorKey *key);
+const gchar *         clutter_animator_key_get_property_name (const ClutterAnimatorKey *key);
 GType                 clutter_animator_key_get_property_type (const ClutterAnimatorKey *key);
 gulong                clutter_animator_key_get_mode          (const ClutterAnimatorKey *key);
 gdouble               clutter_animator_key_get_progress      (const ClutterAnimatorKey *key);
