@@ -78,11 +78,11 @@ clutter_input_device_dispose (GObject *gobject)
 
   g_free (device->device_name);
 
-  if (device->device_mode == CLUTTER_INPUT_MODE_SLAVE)
-    _clutter_input_device_remove_slave (device->associated, device);
-
   if (device->associated != NULL)
     {
+      if (device->device_mode == CLUTTER_INPUT_MODE_SLAVE)
+        _clutter_input_device_remove_slave (device->associated, device);
+
       _clutter_input_device_set_associated_device (device->associated, NULL);
       g_object_unref (device->associated);
       device->associated = NULL;
@@ -785,7 +785,7 @@ clutter_input_device_get_pointer_stage (ClutterInputDevice *device)
  *
  * Since: 1.2
  */
-G_CONST_RETURN gchar *
+const gchar *
 clutter_input_device_get_device_name (ClutterInputDevice *device)
 {
   g_return_val_if_fail (CLUTTER_IS_INPUT_DEVICE (device), NULL);
