@@ -438,6 +438,13 @@ get_color_src_info (const char *mark,
       array_len = G_N_ELEMENTS (tex_combine_color_sources);
     }
 
+  if (len >= 8 &&
+      strncmp (mark, "TEXTURE_", 8) == 0 &&
+      g_ascii_isdigit (mark[8]))
+    {
+      return &tex_combine_texture_n_color_source;
+    }
+
   for (i = 0; i < array_len; i++)
     {
       if (len >= sources[i].name_len
@@ -445,13 +452,6 @@ get_color_src_info (const char *mark,
         return &sources[i];
     }
 
-  if (len >= 9 &&
-      strncmp (mark, "TEXTURE_", 8) == 0 &&
-      g_ascii_isdigit (mark[8]))
-    {
-      return &tex_combine_texture_n_color_source;
-    }
-
   return NULL;
 }
 
@@ -477,8 +477,8 @@ parse_argument (const char *string, /* original user string */
                 GError **error)
 {
   const char *p = *ret_p;
-  const char *mark;
-  const char *error_string;
+  const char *mark = NULL;
+  const char *error_string = NULL;
   ParserArgState state = PARSER_ARG_STATE_START;
   gboolean parsing_factor = FALSE;
 
