@@ -59,7 +59,7 @@ static ClutterBackendGLX *backend_singleton = NULL;
 
 static gchar    *clutter_vblank_name = NULL;
 
-G_CONST_RETURN gchar*
+const gchar*
 _clutter_backend_glx_get_vblank_method (void)
 {
   return clutter_vblank_name;
